@@ -241,7 +241,7 @@ int print_attributes_encoding(Dwarf_Debug dbg,Dwarf_Error *);
 
 /* Detailed tag and attributes usage */
 int print_tag_attributes_usage(void);
-void record_tag_usage(int tag);
+void record_tag_usage(Dwarf_Half tag);
 void reset_usage_rate_tag_trees(void);
 
 int  print_section_groups_data(Dwarf_Debug dbg,Dwarf_Error *);
@@ -379,9 +379,6 @@ dd_print_sig8_target(Dwarf_Debug dbg,
 
 Dwarf_Bool dd_form_refers_local_info(Dwarf_Half form);
 
-
-
-
 #ifdef __cplusplus
 }
 #endif
